==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/TemplateInstanceStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TemplateInstanceStatusBuilder extends TemplateInstanceStatusFluentImpl<TemplateInstanceStatusBuilder> implements VisitableBuilder<TemplateInstanceStatus,TemplateInstanceStatusBuilder>{
  public TemplateInstanceStatusBuilder() {
    this(false);
  }
  public TemplateInstanceStatusBuilder(Boolean validationEnabled) {
    this(new TemplateInstanceStatus(), validationEnabled);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TemplateInstanceStatus(), validationEnabled);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent,TemplateInstanceStatus instance) {
    this(fluent, instance, false);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent,TemplateInstanceStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withObjects(instance.getObjects());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatus instance) {
    this(instance,false);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withObjects(instance.getObjects());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TemplateInstanceStatusFluent<?> fluent;
  Boolean validationEnabled;
  public TemplateInstanceStatus build() {
    TemplateInstanceStatus buildable = new TemplateInstanceStatus(fluent.getConditions(),fluent.getObjects());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/TemplateInstanceStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TemplateInstanceStatusBuilder extends TemplateInstanceStatusFluent<TemplateInstanceStatusBuilder> implements VisitableBuilder<TemplateInstanceStatus,TemplateInstanceStatusBuilder>{
  public TemplateInstanceStatusBuilder() {
    this(false);
  }
  public TemplateInstanceStatusBuilder(Boolean validationEnabled) {
    this(new TemplateInstanceStatus(), validationEnabled);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TemplateInstanceStatus(), validationEnabled);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent,TemplateInstanceStatus instance) {
    this(fluent, instance, false);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatusFluent<?> fluent,TemplateInstanceStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new TemplateInstanceStatus());

    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withObjects(instance.getObjects());
      fluent.withConditions(instance.getConditions());
      fluent.withObjects(instance.getObjects());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatus instance) {
    this(instance,false);
  }
  public TemplateInstanceStatusBuilder(TemplateInstanceStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new TemplateInstanceStatus());

    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withObjects(instance.getObjects());
      this.withConditions(instance.getConditions());
      this.withObjects(instance.getObjects());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TemplateInstanceStatusFluent<?> fluent;
  Boolean validationEnabled;
  public TemplateInstanceStatus build() {
    TemplateInstanceStatus buildable = new TemplateInstanceStatus(fluent.buildConditions(),fluent.buildObjects());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
